% test for equality of variances 

% Levene und Brown-Forsythe-Tests (Varianzhomogenitt)
% Eine wichtige Voraussetzung bei der Durchfhrung von Varianzanalysen 
% (ANOVA und t-Test fr Mittelwertvergleiche) ist die Gleichheit der 
% Varianzen in den zu untersuchenden Gruppen (Varianzhomogenitt). Zwei 
% mchtige und oft verwendete Tests zur berprfung dieser Voraussetzung 
% sind der Levene-Test und dessen Modifikation nach Brown-Forsythe. Man 
% sollte jedoch beachten, dass 
% (1) die Varianzhomogenitt normalerweise keine so entscheidende 
% Voraussetzung fr die Durchfhrung einer ANOVA ist, dies gilt besonders
% fr balancierte Designs (mit gleichen Stichprobengren n; siehe auch 
% ANOVA: Homogenitt von Varianzen und Kovarianzen), und dass 
% (2) diese Tests, wie unten beschrieben, nicht immer sehr robust sind 
% (z. B. bezeichneten Glass und Hopkins, 1996, S. 436 die Tests als 
% "fatally flawed", siehe dazu auch unten die Beschreibung beider Tests). 
% Wenn Sie wegen einer mglichen Verletzung der Voraussetzung der 
% Varianzhomogenitt unsicher sind, ist es immer empfehlenswert, die 
% Analyse mit einem nichtparametrischen Verfahren zu wiederholen.
%
% Levene-Test (Varianzhomogenitt): Fr jede abhngige Variable wird eine 
% Varianzanalyse fr die Werte der absoluten Abweichungen von den 
% entsprechenden Gruppenmittelwerten durchgefhrt. Wenn der Levene-Test 
% statistisch signifikant ist, sollte die Hypothese homogener Varianzen 
% abgelehnt werden.
%
% Brown & Forsythe Test (Varianzhomogenitt): In jngster Vergangenheit 
% ist die Leistungsfhigkeit des Levene-Test fr ungleiche Varianzen durch 
% einige Autoren (z. B. Glass und Hopkins, 1996) in Frage gestellt worden. 
% Insbesondere knnen die absoluten Abweichungen von den Gruppenmittelwerten 
% stark verzerrt sein. Folglich wre die Normalverteilungs-Voraussetzung der
% ANOVA fr diese absoluten Abweichungen oft verletzt. Hieraus ergibt sich
% ein besonderes Problem, wenn zwei oder mehr zu vergleichende Stichproben 
% unterschiedlich gro sind. Brown und Forsythe (1974) stellten einen dem 
% Levene-Test sehr hnlichen aber viel robusteren Test vor. Anstatt die 
% ANOVA fr die Abweichungen vom Gruppenmittelwert durchzufhren, wird die 
% Analyse fr die Abweichungen von den Gruppen-Medianen durchgefhrt. 
% Olejnik und Algina (1987) zeigten, dass dieser Test sehr genaue 
% Fehlerwahrscheinlichkeiten ergibt, auch wenn die zugrundeliegenden 
% Verteilungen der Ursprungsdaten signifikant von der Normalverteilung 
% abweichen. Jedoch zeigten Glass und Hopkins (1996, S. 436), dass sowohl 
% der Test von Levene, als auch die Modifikation nach Brown-Forsythe einen 
% Nachteil haben, den die Autoren "fatal flaw" genannt haben: Beide Tests 
% basieren auf der Annahme, dass die absoluten Abweichungen von Mittelwert 
% oder Median der Varianzhomogenitt gengen. Somit ist weiterhin unklar, 
% wie robust die Tests bei heterogenen Varianzen und ungleichen 
% Stichprobengren sind.

% Quelle: http://www.statsoft.de/glossary/L/LeveneandBrownForsythetestsforhomogeneityofvariancesHOV.htm


clear all
close all

datasets = {'OF'};
% pn = 'raw_data_ydiffs\';
testtype = 'BrownForsythe';

datacoding = 'OF'; % possible values: EAF or OF
if strcmp(datacoding,'EAF'),
    allbats=[4 2 5 3];
    batnumbers =[3 4 6 7];
elseif strcmp(datacoding,'OF'),
    allbats=2:5;
    batnumbers =allbats;
end

not_significant = zeros(1,numel(datasets));

for n = 1:numel(datasets),
    load(['..\flightpathdata\EAFvsOF_data\ydiffs_' datasets{n} '.mat'])
    
    for bc = 1:size(y_1a,1),
        % fligh dir LR: (n,bc,1); flight dir RL: (n,bc,2)
        LR = [y_1a{bc,1}; y_1a{bc,2}];
        groupLR = [ones(1,numel(y_1a{bc,1})) ones(1,numel(y_1a{bc,2}))*2];
        RL = [y_1a{bc,5}; y_1a{bc,6}];
        groupRL = [ones(1,numel(y_1a{bc,5})) ones(1,numel(y_1a{bc,6}))*2];
        p(n,bc,1) = vartestn(LR,groupLR,'TestType',testtype,'Display','off');
        p(n,bc,2) = vartestn(RL,groupRL,'TestType',testtype,'Display','off');
        if p(n,bc,1)>.05, disp([datasets{n} ': No significant differences for Bat' ...
                num2str(batnumbers(bc)) ', flight direction LR']), ...
        not_significant(n)=not_significant(n)+1; end
        
        if p(n,bc,2)>.05, disp([datasets{n} ': No significant differences for Bat' ...
                num2str(batnumbers(bc)) ', flight direction RL']),...
        not_significant(n)=not_significant(n)+1; end
    end
   	figure(n), hold on
    plot(1:numel(allbats),p(n,:,1),'<b','Markerfacecolor','b')
    plot(1:numel(allbats),p(n,:,2),'>r','Markerfacecolor','r')
    plot([0.5 numel(allbats)+.5],[.05 .05],':k','linewidth',3)
    set(gca,'xtick',1:5,'xticklabel',batnumbers(n,:))
    ylabel('P-value of Brown & Forsythe Test'), xlabel(['Bat #'])
    legend({'left-right','right-left','5% significance level'},'location','best')
%     legend('boxoff');
    title(['Homogeneity of flight paths with ' datasets{n} ' stimuli'], 'fontweight','bold')
end

disp(' ');
disp('Significant differences in Variance (BrownForsythe-Test, Significance Level 5%):');
disp(['Optic Flow: ' num2str(8-not_significant) '/8 tests (4 bats x 2 flight directions)']);
% export_fig('..\figures\homogeneity_OF.jpg')
print(gcf,'..\figures\homogeneity_OF.jpg','-djpeg','-r1200')