%% compare_shift_diff_flowfields_poolall.m
%
% This program aims to compare flight behaviour of our bats in different
% flow fields:
% Bats in this study are:
% - LUANNE
% - SPEEDY
% - ROCKET
% - GENERAL TICKTACK.
% All of these bats participated both in preivious data acquisition runs,
% as well as in the latest experiment.
%
% The flow fields to compare are:
% o EAF - Data was acquired in previous data acqusition run. Whenever
%   possible, data for the comparison is taken from the data set acquired
%   with broad panels (ridge spatial frequency matches the optic ridge
%   spatial frequency used in the current experiment.
% o OF - Most recent data acquisition. Purely optical flow field, produced
%   by applying white stripes (insulation tape) on black (smooth) side
%   walls.
% o OFvsEAF - Most recent data acquisition. Contradicting echo-acoustic
%   flow field (broad panel ridges) and optic (white tape on black walls)
%   flow field. Walls are the same stimuli used in the broad panel EAF
%   paradigm, only modified.
%
% For the comparison, we take asymmetric conditions of all three data sets
% and pool data points over both flight directions.

clear all; %#ok<CLSCR>
close all;
warning('off','all')

plotstyle='errorbar'; % either boxplot or errorbar
rawdata_on=1;
save_on=1;

datasets={'EAF','OF','OFvsEAF'};
EAFdirs = {'../flightpathdata/EAF_broadpaneldata/',...
    '../flightpathdata/EAF_finepaneldata/'};
OFandOFvsEAFdir = {'../flightpathdata/EAFvsOF_data/'};
% bats = {'LUANNE', 'SPEEDY', 'ROCKET', 'TICKTACK'};
bats= {'ROCKET', 'LUANNE','TICKTACK','SPEEDY'};  % new sorting, ascending order
% according to their bat number
% in EAF data acquisition

% plotvariables
walllinewidth=2;
OFcolor = [1 .6 0.07];
midlinecolor=[.7 .7 .7];
wall_x=20;
inner_dims=[.1 .1 -.2 -.2];
inner_dims_plot=[.25 .1 -.4 -.1];
helperleftspace = [0 0.35 0.35 0.35];

% preallocate variables;
asym_devs_medians = NaN(numel(bats),numel(datasets));
asym_devs_25 = NaN(numel(bats),numel(datasets));
asym_devs_75 = NaN(numel(bats),numel(datasets));
% for errorbarplot
medians_Vtop = NaN(numel(bats),numel(datasets));
quartiles25_Vtop = NaN(numel(bats),numel(datasets));
quartiles75_Vtop = NaN(numel(bats),numel(datasets));
medians_Vbottom = NaN(numel(bats),numel(datasets));
quartiles25_Vbottom = NaN(numel(bats),numel(datasets));
quartiles75_Vbottom = NaN(numel(bats),numel(datasets));


% prepare figure settings:
fig_dimensions = [16 12];
rect = [0 0 fig_dimensions];
edgespace=[.7 1.5 .96 1]; % left top right bottom
figure('Units','centimeters','PaperUnits','centimeter',...'Outerposition',rect,...
    'Position',rect,'PaperPosition',rect,'PaperSize',fig_dimensions,...
    'color',[1 1 1]); hold on; axis off;

% now prepare subplots. First images
% example images:
% C = imread('../../flighttunnel2_echoacoustic_vs_optic_flow/StimuliPhotos/EAF.tif');
imobj_EAF = Tiff('../StimuliPhotos/EAF.tif','r');
imagedata_EAF=imobj_EAF.read();
imobj_OF = Tiff('../StimuliPhotos/OF.tif','r');
imagedata_OF=imobj_OF.read();
imobj_EAFvsOF = Tiff('../StimuliPhotos/EAFvsOF.tif','r');
imagedata_EAFvsOF=imobj_EAFvsOF.read();
imobj_EAF.close();
imobj_OF.close();
imobj_EAFvsOF.close();

panelheight=3;
% plot_dims=[1.5 panelheight];
image_dims=panelheight*[size(imagedata_EAF,2)/size(imagedata_EAF,1) 1];
plot_dims=[(fig_dimensions(1)-edgespace(1)-edgespace(3)-image_dims(1))/4 panelheight];
% impos1=[edgespace(1) fig_dimensions(2)-panelheight-edgespace(2) panelheight panelheight];
impos1=[edgespace(1) fig_dimensions(2)-panelheight-edgespace(2) image_dims];
EAF_h(1)=axes('Units','centimeters','Outerposition',impos1,'position',impos1+inner_dims,'Box','off');
% now add image
imagesc(imagedata_EAF), colormap(gray); axis off
text(-.1*size(imagedata_EAF,1),round(size(imagedata_EAF,2)/2.4),'flow','rotation',90,'color','b','fontweight','bold')
text(-.24*size(imagedata_EAF,1),round(size(imagedata_EAF,2)/1.8),'echo-acoustic','rotation',90,'color','b','fontweight','bold')
% impos2=[edgespace(1) fig_dimensions(2)-2*panelheight-edgespace(2) panelheight panelheight];
impos2=[edgespace(1) fig_dimensions(2)-2*panelheight-edgespace(2) image_dims];
OF_h(1)=axes('Units','centimeters','Outerposition',impos2,'position',impos2+inner_dims,'Box','off');
imagesc(imagedata_OF), axis off
text(-.1*size(imagedata_EAF,1),round(size(imagedata_EAF,2)/2.4),'flow','rotation',90,'color',OFcolor,'fontweight','bold')
text(-.24*size(imagedata_EAF,1),round(size(imagedata_EAF,2)/2.3),'optic','rotation',90,'color',OFcolor,'fontweight','bold')
% impos3=[edgespace(1) fig_dimensions(2)-3*panelheight-edgespace(2) panelheight panelheight];
impos3=[edgespace(1) fig_dimensions(2)-3*panelheight-edgespace(2) image_dims];
OFvsEAF_h(1)=axes('Units','centimeters','Outerposition',impos3,'position',impos3+inner_dims,'Box','off');
imagesc(imagedata_EAFvsOF), axis off
text(-.1*size(imagedata_EAF,1),round(size(imagedata_EAF,2)/1.9),'optic flow','rotation',90,'color','k','fontweight','bold')
text(-.24*size(imagedata_EAF,1),round(size(imagedata_EAF,2)/1.6),'echo-acoustic vs.','rotation',90,'color','k','fontweight','bold')
% add instructions how to read the plots
line1ax_pos = impos1+[0 3.5 0 -2.5];
line1ax_h=axes('Units','centimeters','Outerposition',line1ax_pos,'position',...
    line1ax_pos,'Box','off');
plot([0 1], [0 0],'color', [.3 .3 .3], 'linewidth',2); axis off
text(0.1, 0.7, 'VIEW INTO THE TUNNEL' ,'color',[.3 .3 .3])
line2ax_pos = impos1+[6 3.5 3.4 -2.5];
line2ax_h=axes('Units','centimeters','Outerposition',line2ax_pos,'position',...
    line2ax_pos,'Box','off');
plot([0 1], [0 0],'color', [.3 .3 .3], 'linewidth',2); axis off
text(0.03, 0.7, 'SCHEMATIC TOP VIEWS ONTO THE TUNNEL' ,'color',[.3 .3 .3])

for bc=1:numel(bats),
    %     help_dims=[edgespace(1)+panelheight+(bc-1)*plot_dims(1) fig_dimensions(2)-panelheight-edgespace(2) plot_dims];
    help_dims=[edgespace(1)+sum(helperleftspace(1:bc))+image_dims(1)+(bc-1)*plot_dims(1) fig_dimensions(2)-panelheight-edgespace(2) plot_dims];
    
    EAF_h(bc+1)=axes('Units','centimeters','Outerposition',help_dims,...
        'position',help_dims+inner_dims_plot,'Box','off'); hold on; axis off
    % plot midline
    plot([0.6 1.4],[0 0],'-','color',midlinecolor,'Linewidth',2)
    plot([1.6 2.4],[0 0],'-','color',midlinecolor,'Linewidth',2);
    % plot sidewalls
    %     plot([0.6 0.8],[-wall_x -wall_x],[0.9 1.1],[-wall_x -wall_x],'b',[1.2 1.4],[-wall_x -wall_x], 'b-','Linewidth',walllinewidth);
    plot([0.6 0.8],[-wall_x -wall_x], 'b-',[0.9 1.1],[-wall_x -wall_x], 'b-',[1.2 1.4],[-wall_x -wall_x], 'b-','Linewidth',walllinewidth);
    plot([1.6 2.4],[-wall_x -wall_x], 'b-','Linewidth',walllinewidth);
    plot([0.6 1.4],[wall_x wall_x], 'b-','Linewidth',walllinewidth);
    plot([1.6 1.8],[wall_x wall_x], 'b-',[1.9 2.1],[wall_x wall_x],'b-',[2.2 2.4],[wall_x wall_x], 'b-','Linewidth',walllinewidth);
    
    OF_h(bc+1)=axes('Units','centimeters','Outerposition',help_dims+[0 -panelheight 0 0],...
        'position',help_dims+[0 -panelheight 0 0]+inner_dims_plot,'Box','off'); hold on; axis off
    % plot midline
    plot([0.6 1.4],[0 0],'-','color',midlinecolor,'Linewidth',2)
    plot([1.6 2.4],[0 0],'-','color',midlinecolor,'Linewidth',2);
    % plot sidewalls
    plot([0.6 0.8],[-wall_x -wall_x],[0.9 1.1],[-wall_x -wall_x],[1.2 1.4],[-wall_x -wall_x], '-','Linewidth',walllinewidth,'color',OFcolor);
    plot([1.6 2.4],[-wall_x -wall_x], '-','Linewidth',walllinewidth,'color',OFcolor);
    plot([0.6 1.4],[wall_x wall_x], '-','Linewidth',walllinewidth,'color',OFcolor);
    plot([1.6 1.8],[wall_x wall_x],[1.9 2.1],[wall_x wall_x],[2.2 2.4],[wall_x wall_x], '-','Linewidth',walllinewidth,'color',OFcolor);
    
    OFvsEAF_h(bc+1)=axes('Units','centimeters','Outerposition',help_dims+[0 -panelheight*2 0 0],...
        'position',help_dims+[0 -panelheight*2 0 0]+inner_dims_plot,'Box','off'); hold on; axis off
    % plot midline
    plot([0.6 1.4],[0 0],'-','color',midlinecolor,'Linewidth',2);
    plot([1.6 2.4],[0 0],'-','color',midlinecolor,'Linewidth',2);
    % plot sidewalls
    plot([1.6 2.4],[wall_x wall_x], 'b','Linewidth',walllinewidth);
    plot([0.6 0.8],[wall_x wall_x], 'b-',[0.9 1.1],[wall_x wall_x],'b-',[1.2 1.4],[wall_x wall_x], 'b-','Linewidth',walllinewidth);
    plot([0.6 1.4],[-wall_x -wall_x], 'b-','Linewidth',walllinewidth);
    plot([1.6 1.8],[-wall_x -wall_x], 'b-',[1.9 2.1],[-wall_x -wall_x],'b',[2.2 2.4],[-wall_x -wall_x], 'b-','Linewidth',walllinewidth);
    
    wall_x2=wall_x-3;
    plot([0.6 0.8],[-wall_x2 -wall_x2],[0.9 1.1],[-wall_x2 -wall_x2],[1.2 1.4],[-wall_x2 -wall_x2], '-','Linewidth',walllinewidth,'color',OFcolor);
    plot([1.6 2.4],[-wall_x2 -wall_x2], '-','Linewidth',walllinewidth,'color',OFcolor);
    plot([0.6 1.4],[wall_x2 wall_x2], '-','Linewidth',walllinewidth,'color',OFcolor);
    plot([1.6 1.8],[wall_x2 wall_x2],[1.9 2.1],[wall_x2 wall_x2],[2.2 2.4],[wall_x2 wall_x2], '-','Linewidth',walllinewidth,'color',OFcolor);
end

% Data set loop
for dsc = 1:numel(datasets),
    dataset_ind = dsc;
    % preallocate variables:
    datasetdirs = cell(numel(bats),1);
    calibfiles = cell(numel(bats),1);
    % chose the correct data directory
    if dataset_ind == 1,
        % find bat where we need to compare with fine panel data because broad
        % panel is not available: Speedy
        finepanelbat_ind = find(arrayfun(@(x) strcmp(x,'SPEEDY'), bats));
        [datasetdirs{:}] = deal(EAFdirs{1});
        datasetdirs{finepanelbat_ind} = deal(EAFdirs{2});
        datasetstr = '';
        connector = '';
        batnumbers=[3 4 6 7]; % new sorting, ascending according to EAF data acquisition
        [calibfiles{:}]= deal('../calibration_data_coordinates/wallcoordinates.mat');
        calibfiles{finepanelbat_ind} = deal('../calibration_data_coordinates/wallcoordinates_2nddataset.mat');
    elseif dataset_ind > 1,
        [calibfiles{:}]= deal('../calibration_data_coordinates/wallcoordinates_opticvsechoacoustic.mat');
        [datasetdirs{:}] = deal(OFandOFvsEAFdir);
        connector = '_';
        %         batnumbers=[2 3 4 5];
        batnumbers=[4 2 5 3]; % new sorting, ascending according to EAF data acquisition
        if dataset_ind == 2,
            datasetstr = 'OF';
        elseif dataset_ind == 3,
            datasetstr = 'OFvsEAF';
        end
    end
    
    for bc = 1:numel(bats),
        clear result*;
        bat=bats{bc};
        batnum=batnumbers(bc);
        % load results from acoustic raw data analysis; this CANNOT be done
        % before this loop, because we take the data from different data
        % sets in some cases
        flightpathdir = [char(datasetdirs{bc})];
        load([flightpathdir 'ana1_'  'Bat' num2str(batnum) connector ...
            datasetstr '.mat']);
        load(calibfiles{bc}); % load calibration data for flight tunnel
        % transfer from pixels to cm and create bincenters
        pixpcm = (max(xcoords)-min(xcoords))/300;
        tunnel_leftend = min(xcoords);
        tunnel_rightend = max(xcoords);
        min_cms_from_ends = 100;
        min_x = round(tunnel_leftend + min_cms_from_ends*pixpcm); % left boundary for analysis
        max_x = round(tunnel_rightend - min_cms_from_ends*pixpcm); % right boundary for analysis
        
        % now we need to reorder the data in an appropriate format: we want
        % to pool data with the same wall-orientation, independent of the
        % flight direction of the animal. Afterwards, we want to
        % statistically check (using a non-parametric test), if data
        % recorded with one wall/stimulus orientation differs from data
        % acquired with the mirrored wall/stimulus orientation.
        
        % pool data with vertical ridges/stripes on the wall in video's top
        ana_results_Vtop = [ana_results_LR_asymVL ana_results_RL_asymVR];
        Xs_Vtop=squeeze(ana_results_Vtop(7:end,:,1));
        n_vtop(dsc,bc)=size(Xs_Vtop,2);
        Xs_Vtop=reshape(Xs_Vtop,numel(Xs_Vtop),1);
        Ys_Vtop=squeeze(ana_results_Vtop(7:end,:,2));
        Ys_Vtop=reshape(Ys_Vtop,numel(Ys_Vtop),1);
        within2centralm_inds_Vtop=find(Xs_Vtop>=min_x & Xs_Vtop<=max_x);
        
        % pool data with vertical ridges/stripes on the wall in video's
        % bottom
        ana_results_Vbottom = [ana_results_LR_asymVR ana_results_RL_asymVL];
        Xs_Vbottom=squeeze(ana_results_Vbottom(7:end,:,1));
        n_vbottom(dsc,bc)=size(Xs_Vbottom,2);
        Xs_Vbottom=reshape(Xs_Vbottom,numel(Xs_Vbottom),1);
        Ys_Vbottom=squeeze(ana_results_Vbottom(7:end,:,2));
        Ys_Vbottom=reshape(Ys_Vbottom,numel(Ys_Vbottom),1);
        within2centralm_inds_Vbottom=find(Xs_Vbottom>=min_x & Xs_Vbottom<=max_x);
        boxplotmatrix=NaN(max([numel(Ys_Vtop) numel(Ys_Vbottom)]),2);
        boxplotmatrix(1:numel(Ys_Vtop),1)=Ys_Vtop;
        boxplotmatrix(1:numel(Ys_Vbottom),2)=Ys_Vbottom;
        [p(bc,dsc),h(bc,dsc)]=ranksum(Ys_Vtop,Ys_Vbottom);
        ntrials_all(dsc,bc)=n_vtop(dsc,bc)+n_vbottom(dsc,bc);
        
        % calculate medians and 25%-/75%-Quantile:
        medians_Vtop(bc,dsc) = prctile(boxplotmatrix(:,1),50);
        quartiles25_Vtop(bc,dsc) = prctile(boxplotmatrix(:,1),25);
        quartiles75_Vtop(bc,dsc) = prctile(boxplotmatrix(:,1),75);
        medians_Vbottom(bc,dsc) = prctile(boxplotmatrix(:,2),50);
        quartiles25_Vbottom(bc,dsc) = prctile(boxplotmatrix(:,2),25);
        quartiles75_Vbottom(bc,dsc) = prctile(boxplotmatrix(:,2),75);
        % pick the correct axis
        if dsc == 1,
            axes(EAF_h(bc+1));
        elseif dsc == 2,
            axes(OF_h(bc+1));
        elseif dsc == 3,
            axes(OFvsEAF_h(bc+1));
        end
        set(gca,'xlim',[0.5 2.5]);
        errorbarh=gca;
        camroll(90);
        th=-7;
        if dsc == 1, th=th*-1; end
        text(1.65, th, ['n=' num2str(n_vtop(dsc,bc))],'fontsize',8);
        text(.65, th, ['n=' num2str(n_vbottom(dsc,bc))],'fontsize',8);
        
        % reverse x-Axis direction, if plotting EAF data:
        if dsc == 1, set(gca,'xdir','reverse'), end
        
        if strcmp(plotstyle,'boxplot'),
            boxplot(boxplotmatrix,'notch','on')
        elseif strcmp(plotstyle,'errorbar'),
            if rawdata_on,
                % plot rawdata
                Vtop_rawdata=boxplotmatrix(:,1);
                Vtop_rawdata=Vtop_rawdata(~isnan(Vtop_rawdata));
                xax_top=randi([900 1100],1,numel(Vtop_rawdata))/1000;
                if dsc == 1, xax_top=fliplr(xax_top); end
                plot(xax_top,Vtop_rawdata,'.','color','r','markersize',3)
                
                Vbottom_rawdata=boxplotmatrix(:,2);
                Vbottom_rawdata=Vbottom_rawdata(~isnan(Vbottom_rawdata));
                xax_bottom=randi([1900 2100],1,numel(Vbottom_rawdata))/1000;
                if dsc == 1, xax_bottom=fliplr(xax_bottom); end
                plot(xax_bottom,Vbottom_rawdata,'.','color','r','markersize',3)
                
                rawdata_Vtop{bc,dsc} = Vtop_rawdata;
                rawdata_Vbottom{bc,dsc} = Vbottom_rawdata;
            end
            
            
            % plot errorbars
            X = 1:2;
            Y = [medians_Vtop(bc,dsc) medians_Vbottom(bc,dsc)];
            L = [medians_Vtop(bc,dsc)-quartiles25_Vtop(bc,dsc) ...
                medians_Vbottom(bc,dsc)-quartiles25_Vbottom(bc,dsc)];
            U = [quartiles75_Vtop(bc,dsc)-medians_Vtop(bc,dsc) ...
                quartiles75_Vbottom(bc,dsc)-medians_Vbottom(bc,dsc)];
            hErrBar(bc,dsc)=errorbar(X,Y,L,U,'+','markersize',5,...
                'Linewidth',2,'color','k');
            % adjust width of end lines
            %             hb = get(hErrBar(bc,dsc),'children');
            %             Xdata = get(hb(2),'Xdata');
            Xdata = get(hErrBar(bc,dsc),'XData');
            temp = 4:3:length(Xdata);
            temp(3:3:end) = [];
            xleft = temp; xright = temp+1;
            Xdata(xleft) = Xdata(xleft) + .15;
            Xdata(xright) = Xdata(xright) - .15;
            %// Update
            %             set(hb(2),'Xdata',Xdata)
%             set(hErrBar(bc,dsc),'XData');
        end
        
        set(gca,'ylim',[-(wall_x+3) (wall_x+3)],'ydir','reverse');
        set(gca,'XTickLabel',{''}), hold on
        %         if dsc==1, title(bats{bc}(1:3),'fontweight','bold'), end
        if dsc==1, ...
                %                 title(['Bat ' num2str(batnum)],'fontweight','bold');
            text(2.55,10,['Bat ' num2str(batnum)],'fontweight','bold'); , end
        
        if dsc == 3,
            gca;
            axis on;
            set(gca,'YColor',[0 0 0],'XColor',[1 1 1])
            %         set(gca,'YAxisLocation','right')
            set(gca,'ytick',[-15 0 15]); hold on,
        end
    end
end

axes(OFvsEAF_h(3));
% general x-Axis label for all plots:
text(-.1, -22,'Deviation from midline (cm)','fontweight','bold')

% save figure
if save_on==1,
    savedir='../figures/';
    print(gcf,[savedir '\Summary_figure_Vtop_vs_Vbottom'],'-djpeg','-r1200')
end

% plot differences
% dev_Vtop_Vbottom = abs(medians_Vtop - medians_Vbottom);
helpv = ones(size(medians_Vtop,1),1);
dev_Vtop_Vbottom = (medians_Vtop - medians_Vbottom).*[helpv helpv*-1 helpv*-1];
figure, barh=bar(dev_Vtop_Vbottom,1);
set(barh(1),'LineWidth',2,'FaceColor','b');
set(barh(2),'LineWidth',2,'FaceColor',OFcolor);
set(barh(3),'LineWidth',2,'FaceColor','k');
hold on
set(gca, 'xticklabel', {'Bat 3' 'Bat 4' 'Bat 6' 'Bat 7'},'fontsize',15,...
    'fontweight','bold','ylim',[-14.8 14.8])
ylabel('Deviation from midline (cm)')
legend('echo-acoustic flow','optic flow','contradicting optic and echo-acoustic flow',...
    'color','none','location','NorthOutside')
legend('boxoff')
set(gca,'YGrid','on','box','off');
set(gcf,'color',[1 1 1])

if save_on==1,
    savedir='../figures/';
    print(gcf,[savedir '\Summary_median_shift'],'-djpeg','-r1200')
end

% figure, hold on,
% avg_dev_midline=([medians_Vtop + medians_Vbottom.*(-1)])/2;
% avg_plot_matrix = avg_dev_midline.*[helpv helpv*-1 helpv*-1];
% barh2=bar(avg_plot_matrix,1);
% set(barh2(1),'LineWidth',2,'FaceColor','b');
% set(barh2(2),'LineWidth',2,'FaceColor',OFcolor);
% set(barh2(3),'LineWidth',2,'FaceColor','k');
% hold on
% set(gca, 'xticklabel', {'Bat 3' 'Bat 4' 'Bat 6' 'Bat 7'},'fontsize',15,...
%     'fontweight','bold','ylim',[-8 8])
% ylabel('Deviation from midline (cm)')
% legend('echo-acoustic flow','optic flow','contradicting optic and echo-acoustic flow',...
%     'color','none','location','NorthOutside')
% legend('boxoff')
% set(gca,'YGrid','on','box','off');
% set(gcf,'color',[1 1 1])
%
% if save_on
%     savedir=['../figures/'];
%     print(gcf,[savedir '\Summary_mean_deviation_fr_midline'],'-djpeg','-r1200')
% end


smdh = figure;
pooled_data_EAF = NaN(1000,numel(bats));
pooled_data_OF = NaN(1000,numel(bats));
pooled_data_EAFvsOF = NaN(1000,numel(bats));
all_ns = [];
for bc = 1:numel(bats),
    np_EAF = numel([rawdata_Vtop{bc,1}; rawdata_Vbottom{bc,1}]);
    
    pooled_data_EAF(1:np_EAF,bc) =  [rawdata_Vtop{bc,1}; rawdata_Vbottom{bc,1}*(-1)];
    np_OF = numel([rawdata_Vtop{bc,2}; rawdata_Vbottom{bc,2}]);
    pooled_data_OF(1:np_OF,bc) =  [rawdata_Vtop{bc,2}; rawdata_Vbottom{bc,2}*(-1)];
    np_EAFvsOF = numel([rawdata_Vtop{bc,3}; rawdata_Vbottom{bc,3}]);
    pooled_data_EAFvsOF(1:np_EAFvsOF,bc) =  [rawdata_Vtop{bc,3}; rawdata_Vbottom{bc,3}*(-1)];
    
    all_ns(numel(all_ns)+1) = np_EAF;
    all_ns(numel(all_ns)+1) = np_OF;
    all_ns(numel(all_ns)+1) = np_EAFvsOF;
    
    pooled_medians(bc,1) = prctile(pooled_data_EAF(:,bc),50);
    pooled_quartiles25(bc,1) = prctile(pooled_data_EAF(:,bc),25);
    pooled_quartiles75(bc,1) = prctile(pooled_data_EAF(:,bc),75);
    
    pooled_medians(bc,2) = prctile(pooled_data_OF(:,bc),50);
    pooled_quartiles25(bc,2) = prctile(pooled_data_OF(:,bc),25);
    pooled_quartiles75(bc,2) = prctile(pooled_data_OF(:,bc),75);
    
    pooled_medians(bc,3) = prctile(pooled_data_EAFvsOF(:,bc),50);
    pooled_quartiles25(bc,3) = prctile(pooled_data_EAFvsOF(:,bc),25);
    pooled_quartiles75(bc,3) = prctile(pooled_data_EAFvsOF(:,bc),75);
    
    %%% statistics: Kruskal-Wallis test using all raw data from 1 bat;
    %%% - compare all 3 flow field data sets
    %%% - multcompare
    EAF_data = pooled_data_EAF(~isnan(pooled_data_EAF(:,bc)),bc);
    EAF_data = EAF_data*-1; % because everything was calculated with "vertical top/bottom", and in the conflicting condition with OF as reference
    EAF_n = numel(EAF_data);
    OF_data = pooled_data_OF(~isnan(pooled_data_OF(:,bc)),bc);
    OF_n = numel(OF_data);
    EAFvsOF_data = pooled_data_EAFvsOF(~isnan(pooled_data_EAFvsOF(:,bc)),bc);
    EAFvsOF_n = numel(EAFvsOF_data);
    group = [ones(EAF_n,1); 2*ones(OF_n,1); 3*ones(EAFvsOF_n,1)];
    [p_kwt(bc),tbl_kwt,stats_kwt(bc,:)]=kruskalwallis(...
        [EAF_data; OF_data; EAFvsOF_data],group,'off');
    c_kwt{bc}=multcompare(stats_kwt(bc,:),'display','off');
    mult_corrected_ps_EAFxOF(bc) = c_kwt{bc}(1,6);
    mult_corrected_ps_EAFxEAFvsOF(bc) = c_kwt{bc}(2,6);
    mult_corrected_ps_OFxEAFvsOF(bc) = c_kwt{bc}(3,6);
    % test what values are calculated when comparing only 2 flow conditions:
    p_kwt_EAFxOF(bc) = kruskalwallis([EAF_data; OF_data],...
        [ones(EAF_n,1); 2*ones(OF_n,1)],'off');
    p_kwt_EAFxEAFvsOF(bc) = kruskalwallis([EAF_data; EAFvsOF_data],...
        [ones(EAF_n,1); 3*ones(EAFvsOF_n,1)],'off');
    p_kwt_OFxEAFvsOF(bc) = kruskalwallis([OF_data; EAFvsOF_data],...
        [2*ones(OF_n,1); 3*ones(EAFvsOF_n,1)],'off');
    %     figure(100), hold on, subplot(1,4,bc)
    %     plot(ones(1,EAF_n),EAF_data,'bo', 2*ones(1,OF_n),OF_data, 'yo', ...
    %         3*ones(1,EAFvsOF_n),EAFvsOF_data, 'ko')
    %     set(gca,'xlim',[0 4],'ylim',[-50 50])
end
pooled_medians_plotmatrix = pooled_medians.*[helpv helpv*-1 helpv*-1];
barh3=bar(pooled_medians_plotmatrix,1); hold on;
set(barh3(1),'LineWidth',2,'FaceColor','b');
set(barh3(2),'LineWidth',2,'FaceColor',OFcolor);
set(barh3(3),'LineWidth',2,'FaceColor','k');
hold on
set(gca, 'xticklabel', {'Bat 3' 'Bat 4' 'Bat 6' 'Bat 7'},'fontsize',15,...
    'fontweight','bold','ylim',[-15.5 15.5])
ylabel('Deviation from midline (cm)')
legend('echo-acoustic flow','optic flow','contradicting optic and echo-acoustic flow',...
    'color','none','location','NorthOutside')
legend('boxoff')
% errorbar(barh3(1),1:4,pooled_medians(:,1)-pooled_quartiles25(:,1),pooled_quartiles75(:,1)-pooled_medians(:,1))
helpspace = .22;
% EAF:
pooled_medians=pooled_medians.*[helpv helpv*-1 helpv*-1];
pooled_quartiles25=pooled_quartiles25.*[helpv helpv*-1 helpv*-1];
pooled_quartiles75=pooled_quartiles75.*[helpv helpv*-1 helpv*-1];
gr = [.5 .5 .5];
e1h=errorbar((1:4)-helpspace,pooled_medians(:,1),pooled_medians(:,1)-pooled_quartiles25(:,1),...
    pooled_quartiles75(:,1)-pooled_medians(:,1),'.','color',gr,'Linewidth',2);
% OF
e2h=errorbar((1:4),pooled_medians(:,2),pooled_medians(:,2)-pooled_quartiles25(:,2),...
    pooled_quartiles75(:,2)-pooled_medians(:,2),'.','color',gr,'Linewidth',2);
% EAF vs OF
e3h=errorbar((1:4)+helpspace,pooled_medians(:,3),pooled_medians(:,3)-pooled_quartiles25(:,3),...
    pooled_quartiles75(:,3)-pooled_medians(:,3),'.','color',gr,'Linewidth',2);

% add number of trials
h = [];
for bc = 1:numel(bats),
    textoffset = -14.5;
    h(numel(h)+1)=text(bc-helpspace,textoffset,(bc*3)-2, ['n=' num2str(ntrials_all(1,bc))],'color','b');
    h(numel(h)+1)=text(bc,textoffset,(bc*3)-1, ['n=' num2str(ntrials_all(2,bc))],'color',OFcolor);
    h(numel(h)+1)=text(bc+helpspace,textoffset,(bc*3), ['n=' num2str(ntrials_all(3,bc))],'color','k');
end
set(h,'rotation',90,'fontsize',12)
% add significance bars
EAF_Xs = e1h.XData;
OF_Xs = e2h.XData;
EAFvsOF_Xs = e3h.XData;
stats_sigfig = [mult_corrected_ps_EAFxOF, mult_corrected_ps_EAFxEAFvsOF, ...
    mult_corrected_ps_OFxEAFvsOF];
stats_sigfig(stats_sigfig>0.05)=NaN;
ssth=sigstar({... % build group vector for the sigfig function, same order than stats
    [EAF_Xs(1), OF_Xs(1)],[EAF_Xs(2), OF_Xs(2)], [EAF_Xs(3), OF_Xs(3)], ...
    [EAF_Xs(4), OF_Xs(4)], ... until here: all EAF  OF
    [EAF_Xs(1), EAFvsOF_Xs(1)], [EAF_Xs(2), EAFvsOF_Xs(2)], [EAF_Xs(3), ...
    EAFvsOF_Xs(3)], [EAF_Xs(4), EAFvsOF_Xs(4)], ... until here: all EAF x EAFvsOF
    [OF_Xs(1), EAFvsOF_Xs(1)], [OF_Xs(2), EAFvsOF_Xs(2)], [OF_Xs(3), EAFvsOF_Xs(3)]...
    [OF_Xs(4), EAFvsOF_Xs(4)]... until here: all OF x EAFvsOF
    }, stats_sigfig);

if save_on==1,
    savedir='../figures/';
    print(gcf,[savedir '\Summary_dev_fr_midline_bar_errorbar_plot'],'-djpeg','-r1200')
end