%% compare_shift_diff_flowfields_poolall.m
%
% This program aims to compare flight behaviour of our bats in different
% flow fields:
% Bats in this study are:
% - LUANNE
% - SPEEDY
% - ROCKET
% - GENERAL TICKTACK.
% All of these bats participated both in preivious data acquisition runs,
% as well as in the latest experiment.
%
% The flow fields to compare are:
% o EAF - Data was acquired in previous data acqusition run. Whenever
%   possible, data for the comparison is taken from the data set acquired
%   with broad panels (ridge spatial frequency matches the optic ridge
%   spatial frequency used in the current experiment.
% o OF - Most recent data acquisition. Purely optical flow field, produced
%   by applying white stripes (insulation tape) on black (smooth) side
%   walls.
% o OFvsEAF - Most recent data acquisition. Contradicting echo-acoustic
%   flow field (broad panel ridges) and optic (white tape on black walls)
%   flow field. Walls are the same stimuli used in the broad panel EAF
%   paradigm, only modified.
%
% For the comparison, we take asymmetric conditions of all three data sets
% and pool data points over both flight directions.

clear all
close all

plotstyle='errorbar'; % either boxplot or errorbar
rawdata_on=1;
save_on=0;

datasets={'EAF','OF','OFvsEAF'};
EAFdirs = {'../flightpathdata/EAF_broadpaneldata/',...
    '../flightpathdata/EAF_finepaneldata/'};
OFandOFvsEAFdir = {'../flightpathdata/EAFvsOF_data/'};
% bats = {'LUANNE', 'SPEEDY', 'ROCKET', 'TICKTACK'};
bats= {'ROCKET', 'LUANNE','TICKTACK','SPEEDY'};  % new sorting, ascending order 
                                                 % according to their bat number 
                                                 % in EAF data acquisition

% plotvariables
walllinewidth=2;
OFcolor = [1 .6 0.07];
midlinecolor=[.7 .7 .7];
wall_x=20;
inner_dims=[.1 .1 -.2 -.2];
inner_dims_plot=[.25 .1 -.4 -.1];
helperleftspace = [0 0.35 0.35 0.35];

% preallocate variables;
asym_devs_medians = NaN(numel(bats),numel(datasets));
asym_devs_25 = NaN(numel(bats),numel(datasets));
asym_devs_75 = NaN(numel(bats),numel(datasets));
% for errorbarplot
medians_Vtop = NaN(numel(bats),numel(datasets));
quartiles25_Vtop = NaN(numel(bats),numel(datasets));
quartiles75_Vtop = NaN(numel(bats),numel(datasets));
medians_Vbottom = NaN(numel(bats),numel(datasets));
quartiles25_Vbottom = NaN(numel(bats),numel(datasets));
quartiles75_Vbottom = NaN(numel(bats),numel(datasets));


% prepare figure settings:
fig_dimensions = [16 12];
rect = [0 0 fig_dimensions];
edgespace=[.7 1.5 .96 1]; % left top right bottom
figure('Units','centimeters','PaperUnits','centimeter',...'Outerposition',rect,...
    'Position',rect,'PaperPosition',rect,'PaperSize',fig_dimensions,...
    'color',[1 1 1]); hold on; axis off

% now prepare subplots. First images
% example images:
% C = imread('../../flighttunnel2_echoacoustic_vs_optic_flow/StimuliPhotos/EAF.tif');
imobj_EAF = Tiff('../StimuliPhotos/EAF.tif','r');
imagedata_EAF=imobj_EAF.read();
imobj_OF = Tiff('../StimuliPhotos/OF.tif','r');
imagedata_OF=imobj_OF.read();
imobj_EAFvsOF = Tiff('../StimuliPhotos/EAFvsOF.tif','r');
imagedata_EAFvsOF=imobj_EAFvsOF.read();
imobj_EAF.close();
imobj_OF.close();
imobj_EAFvsOF.close();

panelheight=3;
% plot_dims=[1.5 panelheight];
image_dims=panelheight*[size(imagedata_EAF,2)/size(imagedata_EAF,1) 1];
plot_dims=[(fig_dimensions(1)-edgespace(1)-edgespace(3)-image_dims(1))/4 panelheight];
% impos1=[edgespace(1) fig_dimensions(2)-panelheight-edgespace(2) panelheight panelheight];
impos1=[edgespace(1) fig_dimensions(2)-panelheight-edgespace(2) image_dims];
EAF_h(1)=axes('Units','centimeters','Outerposition',impos1,'position',impos1+inner_dims,'Box','off');
% now add image
imagesc(imagedata_EAF), colormap(gray); axis off
text(-.1*size(imagedata_EAF,1),round(size(imagedata_EAF,2)/2.4),'flow','rotation',90,'color','b','fontweight','bold')
text(-.24*size(imagedata_EAF,1),round(size(imagedata_EAF,2)/1.8),'echo-acoustic','rotation',90,'color','b','fontweight','bold')
% impos2=[edgespace(1) fig_dimensions(2)-2*panelheight-edgespace(2) panelheight panelheight];
impos2=[edgespace(1) fig_dimensions(2)-2*panelheight-edgespace(2) image_dims];
OF_h(1)=axes('Units','centimeters','Outerposition',impos2,'position',impos2+inner_dims,'Box','off');
imagesc(imagedata_OF), axis off
text(-.1*size(imagedata_EAF,1),round(size(imagedata_EAF,2)/2.4),'flow','rotation',90,'color',OFcolor,'fontweight','bold')
text(-.24*size(imagedata_EAF,1),round(size(imagedata_EAF,2)/2.3),'optic','rotation',90,'color',OFcolor,'fontweight','bold')
% impos3=[edgespace(1) fig_dimensions(2)-3*panelheight-edgespace(2) panelheight panelheight];
impos3=[edgespace(1) fig_dimensions(2)-3*panelheight-edgespace(2) image_dims];
OFvsEAF_h(1)=axes('Units','centimeters','Outerposition',impos3,'position',impos3+inner_dims,'Box','off');
imagesc(imagedata_EAFvsOF), axis off
text(-.1*size(imagedata_EAF,1),round(size(imagedata_EAF,2)/1.9),'optic flow','rotation',90,'color','k','fontweight','bold')
text(-.24*size(imagedata_EAF,1),round(size(imagedata_EAF,2)/1.6),'echo-acoustic vs.','rotation',90,'color','k','fontweight','bold')
% add instructions how to read the plots
line1ax_pos = impos1+[0 3.5 0 -2.5]; 
line1ax_h=axes('Units','centimeters','Outerposition',line1ax_pos,'position',...
    line1ax_pos,'Box','off');
plot([0 1], [0 0],'color', [.3 .3 .3], 'linewidth',2); axis off
text(0.1, 0.7, 'VIEW INTO THE TUNNEL' ,'color',[.3 .3 .3])
line2ax_pos = impos1+[6 3.5 3.4 -2.5]; 
line2ax_h=axes('Units','centimeters','Outerposition',line2ax_pos,'position',...
    line2ax_pos,'Box','off');
plot([0 1], [0 0],'color', [.3 .3 .3], 'linewidth',2); axis off
text(0.03, 0.7, 'SCHEMATIC TOP VIEWS ONTO THE TUNNEL' ,'color',[.3 .3 .3])

for bc=1:numel(bats),
    %     help_dims=[edgespace(1)+panelheight+(bc-1)*plot_dims(1) fig_dimensions(2)-panelheight-edgespace(2) plot_dims];
    help_dims=[edgespace(1)+sum(helperleftspace(1:bc))+image_dims(1)+(bc-1)*plot_dims(1) fig_dimensions(2)-panelheight-edgespace(2) plot_dims];
    
    EAF_h(bc+1)=axes('Units','centimeters','Outerposition',help_dims,...
        'position',help_dims+inner_dims_plot,'Box','off'); hold on; axis off
    % plot midline
    plot([0.6 1.4],[0 0],'-','color',midlinecolor,'Linewidth',2)
    plot([1.6 2.4],[0 0],'-','color',midlinecolor,'Linewidth',2);
    % plot sidewalls
    plot([0.6 0.8],[-wall_x -wall_x],[0.9 1.1],[-wall_x -wall_x],'b',[1.2 1.4],[-wall_x -wall_x], 'b-','Linewidth',walllinewidth);
    plot([1.6 2.4],[-wall_x -wall_x], 'b-','Linewidth',walllinewidth);
    plot([0.6 1.4],[wall_x wall_x], 'b-','Linewidth',walllinewidth);
    plot([1.6 1.8],[wall_x wall_x],[1.9 2.1],[wall_x wall_x],'b',[2.2 2.4],[wall_x wall_x], 'b-','Linewidth',walllinewidth);
    
    OF_h(bc+1)=axes('Units','centimeters','Outerposition',help_dims+[0 -panelheight 0 0],...
        'position',help_dims+[0 -panelheight 0 0]+inner_dims_plot,'Box','off'); hold on; axis off
    % plot midline
    plot([0.6 1.4],[0 0],'-','color',midlinecolor,'Linewidth',2)
    plot([1.6 2.4],[0 0],'-','color',midlinecolor,'Linewidth',2);
    % plot sidewalls
    plot([0.6 0.8],[-wall_x -wall_x],[0.9 1.1],[-wall_x -wall_x],[1.2 1.4],[-wall_x -wall_x], '-','Linewidth',walllinewidth,'color',OFcolor);
    plot([1.6 2.4],[-wall_x -wall_x], '-','Linewidth',walllinewidth,'color',OFcolor);
    plot([0.6 1.4],[wall_x wall_x], '-','Linewidth',walllinewidth,'color',OFcolor);
    plot([1.6 1.8],[wall_x wall_x],[1.9 2.1],[wall_x wall_x],[2.2 2.4],[wall_x wall_x], '-','Linewidth',walllinewidth,'color',OFcolor);

    OFvsEAF_h(bc+1)=axes('Units','centimeters','Outerposition',help_dims+[0 -panelheight*2 0 0],...
        'position',help_dims+[0 -panelheight*2 0 0]+inner_dims_plot,'Box','off'); hold on; axis off
    % plot midline
    plot([0.6 1.4],[0 0],'-','color',midlinecolor,'Linewidth',2)
    plot([1.6 2.4],[0 0],'-','color',midlinecolor,'Linewidth',2);
    % plot sidewalls
    plot([1.6 2.4],[wall_x wall_x], 'b','Linewidth',walllinewidth);
    plot([0.6 0.8],[wall_x wall_x],[0.9 1.1],[wall_x wall_x],'b-',[1.2 1.4],[wall_x wall_x], 'b-','Linewidth',walllinewidth);
    plot([0.6 1.4],[-wall_x -wall_x], 'b-','Linewidth',walllinewidth);
    plot([1.6 1.8],[-wall_x -wall_x],[1.9 2.1],[-wall_x -wall_x],'b',[2.2 2.4],[-wall_x -wall_x], 'b-','Linewidth',walllinewidth);
    
    wall_x2=wall_x-3;
    plot([0.6 0.8],[-wall_x2 -wall_x2],[0.9 1.1],[-wall_x2 -wall_x2],[1.2 1.4],[-wall_x2 -wall_x2], '-','Linewidth',walllinewidth,'color',OFcolor);
    plot([1.6 2.4],[-wall_x2 -wall_x2], '-','Linewidth',walllinewidth,'color',OFcolor);
    plot([0.6 1.4],[wall_x2 wall_x2], '-','Linewidth',walllinewidth,'color',OFcolor);
    plot([1.6 1.8],[wall_x2 wall_x2],[1.9 2.1],[wall_x2 wall_x2],[2.2 2.4],[wall_x2 wall_x2], '-','Linewidth',walllinewidth,'color',OFcolor);
end

% Data set loop
for dsc = 1:numel(datasets),
    dataset_ind = dsc;
    % preallocate variables:
    datasetdirs = cell(numel(bats),1);
    calibfiles = cell(numel(bats),1);
    % chose the correct data directory
    if dataset_ind == 1,
        % find bat where we need to compare with fine panel data because broad
        % panel is not available: Speedy
        finepanelbat_ind = find(arrayfun(@(x) strcmp(x,'SPEEDY'), bats));
        [datasetdirs{:}] = deal(EAFdirs{1});
        datasetdirs{finepanelbat_ind} = deal(EAFdirs{2});
        datasetstr = '';
        connector = '';
        batnumbers=[3 4 6 7]; % new sorting, ascending according to EAF data acquisition
        [calibfiles{:}]= deal('../calibration_data_coordinates/wallcoordinates.mat');
        calibfiles{finepanelbat_ind} = deal('../calibration_data_coordinates/wallcoordinates_2nddataset.mat');
    elseif dataset_ind > 1,
        [calibfiles{:}]= deal('../calibration_data_coordinates/wallcoordinates_opticvsechoacoustic.mat');
        [datasetdirs{:}] = deal(OFandOFvsEAFdir);
        connector = '_';
        %         batnumbers=[2 3 4 5];
        batnumbers=[4 2 5 3]; % new sorting, ascending according to EAF data acquisition
        if dataset_ind == 2,
            datasetstr = 'OF';
        elseif dataset_ind == 3,
            datasetstr = 'OFvsEAF';
        end
    end
    
    for bc = 1:numel(bats),
        clear result*
        bat=bats{bc};
        batnum=batnumbers(bc);
        % load results from acoustic raw data analysis; this CANNOT be done
        % before this loop, because we take the data from different data
        % sets in some cases
        flightpathdir = char(datasetdirs{bc});
        load([flightpathdir 'ana1_'  'Bat' num2str(batnum) connector ...
            datasetstr '.mat'])
        load(calibfiles{bc}) % load calibration data for flight tunnel
        % transfer from pixels to cm and create bincenters
        pixpcm = (max(xcoords)-min(xcoords))/300;
        tunnel_leftend = min(xcoords);
        tunnel_rightend = max(xcoords);
        min_cms_from_ends = 100;
        min_x = round(tunnel_leftend + min_cms_from_ends*pixpcm); % left boundary for analysis
        max_x = round(tunnel_rightend - min_cms_from_ends*pixpcm); % right boundary for analysis
        
        % now we need to reorder the data in an appropriate format: we want
        % to pool data with the same wall-orientation, independent of the
        % flight direction of the animal. Afterwards, we want to
        % statistically check (using a non-parametric test), if data
        % recorded with one wall/stimulus orientation differs from data
        % acquired with the mirrored wall/stimulus orientation.
        
        % pool data with vertical ridges/stripes on the wall in video's top
        ana_results_Vtop = [ana_results_LR_asymVL ana_results_RL_asymVR];
        Xs_Vtop=squeeze(ana_results_Vtop(7:end,:,1));
        Xs_Vtop=reshape(Xs_Vtop,numel(Xs_Vtop),1);
        Ys_Vtop=squeeze(ana_results_Vtop(7:end,:,2));
        Ys_Vtop=reshape(Ys_Vtop,numel(Ys_Vtop),1);
        within2centralm_inds_Vtop=find(Xs_Vtop>=min_x & Xs_Vtop<=max_x);
        
        % pool data with vertical ridges/stripes on the wall in video's
        % bottom
        ana_results_Vbottom = [ana_results_LR_asymVR ana_results_RL_asymVL];
        Xs_Vbottom=squeeze(ana_results_Vbottom(7:end,:,1));
        Xs_Vbottom=reshape(Xs_Vbottom,numel(Xs_Vbottom),1);
        Ys_Vbottom=squeeze(ana_results_Vbottom(7:end,:,2));
        Ys_Vbottom=reshape(Ys_Vbottom,numel(Ys_Vbottom),1);
        within2centralm_inds_Vbottom=find(Xs_Vbottom>=min_x & Xs_Vbottom<=max_x);
        boxplotmatrix=NaN(max([numel(Ys_Vtop) numel(Ys_Vbottom)]),2);
        boxplotmatrix(1:numel(Ys_Vtop),1)=Ys_Vtop;
        boxplotmatrix(1:numel(Ys_Vbottom),2)=Ys_Vbottom;
        [p(bc,dsc),h(bc,dsc)]=ranksum(Ys_Vtop,Ys_Vbottom);
        
        
        
        % calculate medians and 25%-/75%-Quantile:
        medians_Vtop(bc,dsc) = prctile(boxplotmatrix(:,1),50);
        quartiles25_Vtop(bc,dsc) = prctile(boxplotmatrix(:,1),25);
        quartiles75_Vtop(bc,dsc) = prctile(boxplotmatrix(:,1),75);
        medians_Vbottom(bc,dsc) = prctile(boxplotmatrix(:,2),50);
        quartiles25_Vbottom(bc,dsc) = prctile(boxplotmatrix(:,2),25);
        quartiles75_Vbottom(bc,dsc) = prctile(boxplotmatrix(:,2),75);
        
        % pick the correct axis
        if dsc == 1,
            axes(EAF_h(bc+1));
        elseif dsc == 2,
            axes(OF_h(bc+1));
        elseif dsc == 3,
            axes(OFvsEAF_h(bc+1));
        end
        set(gca,'xlim',[0.5 2.5]);
        errorbarh=gca;
        camroll(90);
        
        % reverse x-Axis direction, if plotting EAF data:
        if dsc == 1, set(gca,'xdir','reverse'), end
        
        if strcmp(plotstyle,'boxplot'),
            boxplot(boxplotmatrix,'notch','on');
        elseif strcmp(plotstyle,'errorbar'),
            if rawdata_on,
                % plot rawdata
                Vtop_rawdata=boxplotmatrix(:,1);
                Vtop_rawdata=Vtop_rawdata(~isnan(Vtop_rawdata));
                xax_top=randi([900 1100],1,numel(Vtop_rawdata))/1000;
                if dsc == 1, xax_top=fliplr(xax_top); end
                plot(xax_top,Vtop_rawdata,'.','color','r','markersize',3)
                
                Vbottom_rawdata=boxplotmatrix(:,2);
                Vbottom_rawdata=Vbottom_rawdata(~isnan(Vbottom_rawdata));
                xax_bottom=randi([1900 2100],1,numel(Vbottom_rawdata))/1000;
                if dsc == 1, xax_bottom=fliplr(xax_bottom); end
                plot(xax_bottom,Vbottom_rawdata,'.','color','r','markersize',3)
            end
            

            % plot errorbars
            X = 1:2;
            Y = [medians_Vtop(bc,dsc) medians_Vbottom(bc,dsc)];
            L = [medians_Vtop(bc,dsc)-quartiles25_Vtop(bc,dsc) ...
                medians_Vbottom(bc,dsc)-quartiles25_Vbottom(bc,dsc)];
            U = [quartiles75_Vtop(bc,dsc)-medians_Vtop(bc,dsc) ...
                quartiles75_Vbottom(bc,dsc)-medians_Vbottom(bc,dsc)];
            hErrBar(bc,dsc)=errorbar(X,Y,L,U,'+','markersize',5,...
                'Linewidth',2,'color','k');
            % adjust width of end lines
%             hb = get(hErrBar(bc,dsc),'children');
%             Xdata = get(hb(2),'Xdata');
            Xdata = get(hErrBar(bc,dsc),'XData');
            temp = 4:3:length(Xdata);
            temp(3:3:end) = [];
            xleft = temp; xright = temp+1;
            Xdata(xleft) = Xdata(xleft) + .15;
            Xdata(xright) = Xdata(xright) - .15;
            %// Update
            %             set(hb(2),'Xdata',Xdata)
            set(hErrBar(bc,dsc),'XData')
        end
        
        set(gca,'ylim',[-(wall_x+3) (wall_x+3)],'ydir','reverse')
        set(gca,'XTickLabel',{''}), hold on
        %         if dsc==1, title(bats{bc}(1:3),'fontweight','bold'), end
        if dsc==1, ...
%                 title(['Bat ' num2str(batnum)],'fontweight','bold'); 
                text(2.55,10,['Bat ' num2str(batnum)],'fontweight','bold') , 
        end
        
        if dsc == 3,
        gca;
        axis on
        set(gca,'YColor',[0 0 0],'XColor',[1 1 1])
%         set(gca,'YAxisLocation','right')
        set(gca,'ytick',[-15 0 15]); hold on,
        end
    end
end  

axes(OFvsEAF_h(3));
% general x-Axis label for all plots:
text(-.1, -22,'Deviation from midline (cm)','fontweight','bold')

% save figure
if save_on
    savedir='../figures/';
    print(gcf,[savedir '\Summary_figure_Vtop_vs_Vbottom'],'-djpeg','-r1200')
end

% plot differences
% dev_Vtop_Vbottom = abs(medians_Vtop - medians_Vbottom);
helpv = ones(size(medians_Vtop,1),1);
dev_Vtop_Vbottom = (medians_Vtop - medians_Vbottom).*[helpv helpv*-1 helpv*-1];
figure, barh=bar(dev_Vtop_Vbottom,1); 
set(barh(1),'LineWidth',2,'FaceColor','b');
set(barh(2),'LineWidth',2,'FaceColor',OFcolor);
set(barh(3),'LineWidth',2,'FaceColor','k');
set(gca, 'xticklabel', {'Bat 3' 'Bat 4' 'Bat 6' 'Bat 7'},'fontsize',15,...
    'fontweight','bold','ylim',[-6.8 14.8]);
ylabel('Deviation from midline (cm)');
legend('echo-acoustic flow','optic flow','contradicting optic and echo-acoustic flow',...
    'color','none','location','NorthOutside');
legend('boxoff')
set(gca,'YGrid','on','box','off');
set(gcf,'color',[1 1 1])
if save_on
    savedir='../figures/';
    print(gcf,[savedir '\Summary_median_shift'],'-djpeg','-r1200')
end